﻿//INSTANT C# NOTE: Formerly VB project-level imports:
using System;
using System.Collections;
using System.Data;
using System.Diagnostics;
using System.Drawing;
using System.Windows.Forms;

namespace Example
{
	public partial class FormConfigureAlarmNotification
	{
		// The GetNetworkNodes Function returns a list of Network Nodes from the local system as a String Array.
		// Returns empty String Array if no Network Nodes are found.
		internal FormConfigureAlarmNotification()
		{
			InitializeComponent();
		}

		private void ButtonGetNetworkNodes_Click(object sender, System.EventArgs e)
		{
			System.Windows.Forms.Cursor.Current = Cursors.WaitCursor;
			string[] NetworkNodes = null;
//INSTANT C# NOTE: Commented this declaration since looping variables in 'foreach' loops are declared in the 'foreach' header in C#:
//			string NetworkNode = null;
			ComboBoxNetworkNodes.Items.Clear();
			ComboBoxNetworkNodes.Items.Add("localhost");
			ComboBoxNetworkNodes.Items.Add("www.opcsystemsserver.com");

			NetworkNodes = ModuleNetworkNode.OPCSystemsComponent1.GetNetworkNodes();
			if (NetworkNodes.GetLength(0) < 1)
			{
			}
			else
			{
				foreach (string NetworkNode in NetworkNodes)
				{
					ComboBoxNetworkNodes.Items.Add(NetworkNode);
				}
			}
			ComboBoxNetworkNodes.SelectedIndex = 0;

		}

		private void ComboBoxNetworkNodes_SelectedIndexChanged(object sender, System.EventArgs e)
		{
			TextBoxNetworkNode.Text = ComboBoxNetworkNodes.SelectedItem.ToString();
		}

		// The GetAlarmNotificationNames Function returns a list of the Alarm Notification Groups.
		// Returns Empty String Array if service is not reachable.
		// NetworkNode is the name of the network node of the OPC Systems Service to connect to.  Leave blank for localhost connection.
		// Optional ErrorString will be set to Success when function is successful and an error message when in error.
		private void ButtonGetAlarmNotificationNames_Click(object sender, System.EventArgs e)
		{
			System.Windows.Forms.Cursor.Current = Cursors.WaitCursor;
			ComboBoxGetAlarmNotificationNames.Items.Clear();
			string[] Groups = null;
//INSTANT C# NOTE: Commented this declaration since looping variables in 'foreach' loops are declared in the 'foreach' header in C#:
//			string Group = null;
			string ErrorString = "";
			Groups = ModuleNetworkNode.OPCSystemsComponent1.GetAlarmNotificationNames(TextBoxNetworkNode.Text, ref ErrorString);
			if (ErrorString == "Success")
			{
				foreach (string Group in Groups)
				{
					ComboBoxGetAlarmNotificationNames.Items.Add(Group);
				}
				if (ComboBoxGetAlarmNotificationNames.Items.Count > 0)
				{
					ComboBoxGetAlarmNotificationNames.SelectedIndex = 0;
				}
			}
			else
			{
				MessageBox.Show(ErrorString, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
			}
		}

		private void ComboBoxGetAlarmNotificationNames_SelectedIndexChanged(object sender, System.EventArgs e)
		{
			TextBoxAlarmNotificationGroup.Text = ComboBoxGetAlarmNotificationNames.SelectedItem.ToString();
		}

		// The AddAlarmNotificationGroup Function adds a Alarm Notification Group to the existing Alarm Notification configuration.
		// Returns -1 if service is not reachable.
		// Returns 1 if successful.
		// Returns 0 if the Group already exists or adding the Group failed.
		// Group is the name of the Group to add.
		// NetworkNode is the name of the network node of the OPC Systems Service to connect to.  Leave blank for localhost connection.
		// Optional ErrorString will be set to Success when function is successful and an error message when in error.
		private void ButtonAddAlarmNotificationGroup_Click(object sender, System.EventArgs e)
		{
			System.Windows.Forms.Cursor.Current = Cursors.WaitCursor;
			Int32 ResultInt32 = 0;
			string ErrorString = "";
			ResultInt32 = ModuleNetworkNode.OPCSystemsComponent1.AddAlarmNotificationGroup(TextBoxAlarmNotificationGroup.Text, TextBoxNetworkNode.Text, ref ErrorString);
			if (ResultInt32 == -1)
			{
				LabelAddAlarmNotificationGroupResult.Text = "OPC Systems Service not reached.";
			}
			else if (ResultInt32 == 1)
			{
				LabelAddAlarmNotificationGroupResult.Text = "Group successfully added.";
			}
			else
			{
				LabelAddAlarmNotificationGroupResult.Text = ErrorString;
			}
		}

		// The RemoveAlarmNotificationGroup Function removes a Alarm Notification Group from the existing Alarm Notification configuration.
		// Returns -1 if service is not reachable.
		// Returns 1 if successful.
		// Returns 0 if the Group does not exist or removing the Group failed.
		// Group is the name of the Group to remove.
		// NetworkNode is the name of the network node of the OPC Systems Service to connect to.  Leave blank for localhost connection.
		// Optional ErrorString will be set to Success when function is successful and an error message when in error.
		private void ButtonRemoveAlarmNotificationGroup_Click(object sender, System.EventArgs e)
		{
			System.Windows.Forms.Cursor.Current = Cursors.WaitCursor;
			Int32 ResultInt32 = 0;
			string ErrorString = "";
			ResultInt32 = ModuleNetworkNode.OPCSystemsComponent1.RemoveAlarmNotificationGroup(TextBoxAlarmNotificationGroup.Text, TextBoxNetworkNode.Text, ref ErrorString);
			if (ResultInt32 == -1)
			{
				LabelRemoveAlarmNotificationGroupResult.Text = "OPC Systems Service not reached.";
			}
			else if (ResultInt32 == 1)
			{
				LabelRemoveAlarmNotificationGroupResult.Text = "Group successfully removed.";
			}
			else
			{
				LabelRemoveAlarmNotificationGroupResult.Text = ErrorString;
			}
		}

		// The GetAlarmNotificationParameterStrings Function returns an array of Strings containing all property types available for each Alarm Notification Group.
		// Returns Empty String Array if service is not reachable.
		// Returns a String Array of property types for all possible Parameters for a Alarm Notification Group.
		// NetworkNode is the name of the network node of the OPC Systems Service to connect to.  Leave blank for localhost connection.
		private void ButtonGetAlarmNotificationParameterStrings_Click(object sender, System.EventArgs e)
		{
			System.Windows.Forms.Cursor.Current = Cursors.WaitCursor;
			ComboBoxGetAlarmNotificationParameterStrings.Items.Clear();
			string[] Parameters = null;
//INSTANT C# NOTE: Commented this declaration since looping variables in 'foreach' loops are declared in the 'foreach' header in C#:
//			string Parameter = null;
			Parameters = ModuleNetworkNode.OPCSystemsComponent1.GetAlarmNotificationParameterStrings(TextBoxNetworkNode.Text);
			foreach (string Parameter in Parameters)
			{
				ComboBoxGetAlarmNotificationParameterStrings.Items.Add(Parameter);
			}
			if (ComboBoxGetAlarmNotificationParameterStrings.Items.Count > 0)
			{
				ComboBoxGetAlarmNotificationParameterStrings.SelectedIndex = 1;
			}
		}

		private void ComboBoxGetAlarmNotificationParameterStrings_SelectedIndexChanged(object sender, System.EventArgs e)
		{
			TextBoxParameter.Text = ComboBoxGetAlarmNotificationParameterStrings.SelectedItem.ToString();
		}

		// The GetAlarmNotification_Parameter_Value Function returns an object value for the Alarm Notification Group and Parameter specified.
		// Returns nothing if service is not reachable.
		// Parameter is a String of the Parameter Type desired of the Alarm Notification Group.
		// Group is a String of the Alarm Notification Group desired.
		// NetworkNode is the name of the network node of the OPC Systems Service to connect to.  Leave blank for localhost connection.
		// Optional ErrorString will be set to Success when function is successful and an error message when in error.
		private void ButtonGetAlarmNotification_Parameter_Value_Click(object sender, System.EventArgs e)
		{
			System.Windows.Forms.Cursor.Current = Cursors.WaitCursor;
			object ResultObject = null;
			string ErrorString = "";
			ResultObject = ModuleNetworkNode.OPCSystemsComponent1.GetAlarmNotification_Parameter_Value(TextBoxParameter.Text, TextBoxAlarmNotificationGroup.Text, TextBoxNetworkNode.Text, ref ErrorString);
			if (ErrorString == "Success")
			{
				if (ResultObject == null)
				{
					LabelGetAlarmNotification_Parameter_ValueResult.Text = "";
					TextBoxValueToSet.Text = "";
				}
				else
				{
					try
					{
						LabelGetAlarmNotification_Parameter_ValueResult.Text = ResultObject.ToString();
						TextBoxValueToSet.Text = ResultObject.ToString();
					}
					catch (Exception ex)
					{
						LabelGetAlarmNotification_Parameter_ValueResult.Text = "Error converting value to string.";
						TextBoxValueToSet.Text = "";
					}
				}
			}
			else
			{
				LabelGetAlarmNotification_Parameter_ValueResult.Text = ErrorString;
				TextBoxValueToSet.Text = "";
			}
		}

		// The GetAlarmNotification_Parameter_Values Function returns an array of object values for the Alarm Notification Group specified.
		// The order of the array corresponds with the GetAlarmNotificationParameterStrings Function order.
		// Returns empty array if service is not reachable.
		// Group is a String of the Alarm Notification Group desired.
		// NetworkNode is the name of the network node of the OPC Systems Service to connect to.  Leave blank for localhost connection.
		// Optional ErrorString will be set to Success when function is successful and an error message when in error.
		private void ButtonGetAlarmNotification_Parameter_Values_Click(object sender, System.EventArgs e)
		{
			System.Windows.Forms.Cursor.Current = Cursors.WaitCursor;
			ComboBoxGetAlarmNotification_Parameter_Values.Items.Clear();
			object[] ResultObjects = null;
//INSTANT C# NOTE: Commented this declaration since looping variables in 'foreach' loops are declared in the 'foreach' header in C#:
//			object ResultObject = null;
			string ResultString = null;
			string ErrorString = "";
			ResultObjects = ModuleNetworkNode.OPCSystemsComponent1.GetAlarmNotification_Parameter_Values(TextBoxAlarmNotificationGroup.Text, TextBoxNetworkNode.Text, ref ErrorString);
			if (ErrorString == "Success")
			{
				foreach (object ResultObject in ResultObjects)
				{
					try
					{
						if (ResultObject == null)
						{
							ResultString = "";
						}
						else
						{
							ResultString = ResultObject.ToString();
						}
						ComboBoxGetAlarmNotification_Parameter_Values.Items.Add(ResultString);
					}
					catch (Exception ex)
					{
						ComboBoxGetAlarmNotification_Parameter_Values.Items.Add("Error Converting Object");
					}
				}
				if (ComboBoxGetAlarmNotification_Parameter_Values.Items.Count > 0)
				{
					ComboBoxGetAlarmNotification_Parameter_Values.SelectedIndex = 1;
				}
			}
			else
			{
				MessageBox.Show(ErrorString, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
			}
		}

		// The SetAlarmNotification_Parameter_Value Function sets an object value for the Alarm Notification Group and Parameter specified.
		// Returns -1 if service is not reachable.
		// Returns 0 if the Group does not exist or the value did not get set correctly.
		// Returns 1 if the function was successful.
		// Parameter is a String of the Parameter Type desired of the Alarm Notification Group.
		// Value is the desired value to set.
		// Group is a String of the Alarm Notification Group desired.
		// NetworkNode is the name of the network node of the OPC Systems Service to connect to.  Leave blank for localhost connection.
		// Optional ErrorString will be set to Success when function is successful and an error message when in error.
		private void ButtonSetAlarmNotification_Parameter_Value_Click(object sender, System.EventArgs e)
		{
			System.Windows.Forms.Cursor.Current = Cursors.WaitCursor;
			Int32 ResultInt32 = 0;
			string ErrorString = "";
			ResultInt32 = ModuleNetworkNode.OPCSystemsComponent1.SetAlarmNotification_Parameter_Value(TextBoxParameter.Text, TextBoxValueToSet.Text, TextBoxAlarmNotificationGroup.Text, TextBoxNetworkNode.Text, ref ErrorString);
			if (ResultInt32 == -1)
			{
				LabelSetAlarmNotification_Parameter_ValueResult.Text = "OPC Systems Service not reached.";
			}
			else if (ResultInt32 == 1)
			{
				LabelSetAlarmNotification_Parameter_ValueResult.Text = "Parameter Successfully Updated.";
			}
			else
			{
				LabelSetAlarmNotification_Parameter_ValueResult.Text = ErrorString;
			}
		}

		// The SaveAlarmNotificationConfiguration Subroutine saves the current Alarm Notification configuration to the specified file path.
		// NetworkNode is the name of the network node of the OPC Systems Service to connect to.  Leave blank for localhost connection.
		// Optional ErrorString will be set to Success when function is successful and an error message when in error.
		private void ButtonSaveAlarmNotificationConfiguration_Click(object sender, System.EventArgs e)
		{
			System.Windows.Forms.Cursor.Current = Cursors.WaitCursor;
			string ErrorString = "";
			ModuleNetworkNode.OPCSystemsComponent1.SaveAlarmNotificationConfiguration(TextBoxFilePath.Text, TextBoxNetworkNode.Text, ref ErrorString);
			if (ErrorString != "Success")
			{
				MessageBox.Show(ErrorString, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
			}
		}

		// The LoadAlarmNotificationConfiguration Subroutine saves the current Alarm Notification configuration to the specified file path.
		// NetworkNode is the name of the network node of the OPC Systems Service to connect to.  Leave blank for localhost connection.
		private void ButtonLoadAlarmNotificationConfiguration_Click(object sender, System.EventArgs e)
		{
			System.Windows.Forms.Cursor.Current = Cursors.WaitCursor;
			string ErrorString = "";
			ModuleNetworkNode.OPCSystemsComponent1.LoadAlarmNotificationConfiguration(TextBoxFilePath.Text, TextBoxNetworkNode.Text, ref ErrorString);
			if (ErrorString != "Success")
			{
				MessageBox.Show(ErrorString, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
			}
		}

	}
}