﻿//INSTANT C# NOTE: Formerly VB project-level imports:
using System;
using System.Collections;
using System.Data;
using System.Diagnostics;
using System.Drawing;
using System.Windows.Forms;

namespace Example
{
	public partial class FormConfigureDriverInterfaces
	{
		// The GetNetworkNodes Function returns a list of Network Nodes from the local system as a String Array.
		// Returns empty String Array if no Network Nodes are found.
		internal FormConfigureDriverInterfaces()
		{
			InitializeComponent();
		}

		private void ButtonGetNetworkNodes_Click(object sender, System.EventArgs e)
		{
			System.Windows.Forms.Cursor.Current = Cursors.WaitCursor;
			string[] NetworkNodes = null;
//INSTANT C# NOTE: Commented this declaration since looping variables in 'foreach' loops are declared in the 'foreach' header in C#:
//			string NetworkNode = null;
			ComboBoxNetworkNodes.Items.Clear();
			ComboBoxNetworkNodes.Items.Add("localhost");
			ComboBoxNetworkNodes.Items.Add("www.opcsystemsserver.com");
			NetworkNodes = ModuleNetworkNode.OPCSystemsComponent1.GetNetworkNodes();
			if (NetworkNodes.GetLength(0) < 1)
			{
			}
			else
			{
				foreach (string NetworkNode in NetworkNodes)
				{
					ComboBoxNetworkNodes.Items.Add(NetworkNode);
				}
			}
			ComboBoxNetworkNodes.SelectedIndex = 0;

		}

		private void ComboBoxNetworkNodes_SelectedIndexChanged(object sender, System.EventArgs e)
		{
			TextBoxNetworkNode.Text = ComboBoxNetworkNodes.SelectedItem.ToString();
		}

		// The GetDriverInterfaceNames Function returns a list of the Driver Interfaces.
		// Returns Empty String Array if service is not reachable.
		// NetworkNode is the name of the network node of the OPC Systems Service to connect to.  Leave blank for localhost connection.
		// ErrorString will be set to Success when function is successful and an error message when in error.
		// RemoteSCADAHostingName is the name of the Live Data Cloud OPC Systems Service to connect to.
		private void ButtonGetDriverIntefaceNames_Click(object sender, System.EventArgs e)
		{
			System.Windows.Forms.Cursor.Current = Cursors.WaitCursor;
			ComboBoxGetDriverInterfaceNames.Items.Clear();
			string[] Groups = null;
//INSTANT C# NOTE: Commented this declaration since looping variables in 'foreach' loops are declared in the 'foreach' header in C#:
//			string Group = null;
			string ErrorString = "";
			Groups = ModuleNetworkNode.OPCSystemsComponent1.GetDriverInterfaceNames(TextBoxNetworkNode.Text, ref ErrorString);
			if (ErrorString == "Success")
			{
				foreach (string Group in Groups)
				{
					ComboBoxGetDriverInterfaceNames.Items.Add(Group);
				}
				if (ComboBoxGetDriverInterfaceNames.Items.Count > 0)
				{
					ComboBoxGetDriverInterfaceNames.SelectedIndex = 0;
				}
			}
			else
			{
				MessageBox.Show(ErrorString, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
			}
		}

		private void ComboBoxGetDriverInterfaceNames_SelectedIndexChanged(object sender, System.EventArgs e)
		{
			TextBoxDriverInterface.Text = ComboBoxGetDriverInterfaceNames.SelectedItem.ToString();
		}

		// The RemoveDriverInterface Function removes a Driver Interface Group from the existing Driver Interface configuration.
		// Returns -1 if service is not reachable.
		// Returns 1 if successful.
		// Returns 0 if the Driver Interface does not exist or removing the Driver Interface failed.
		// Name is the name of the Driver Interface to remove.
		// NetworkNode is the name of the network node of the OPC Systems Service to connect to.  Leave blank for localhost connection.
		// ErrorString will be set to Success when function is successful and an error message when in error.
		// RemoteSCADAHostingName is the name of the Live Data Cloud OPC Systems Service to connect to.
		private void ButtonRemoveDriverInterface_Click(object sender, System.EventArgs e)
		{
			System.Windows.Forms.Cursor.Current = Cursors.WaitCursor;
			Int32 ResultInt32 = 0;
			string ErrorString = "";
			ResultInt32 = ModuleNetworkNode.OPCSystemsComponent1.RemoveDriverInterface(TextBoxDriverInterface.Text, TextBoxNetworkNode.Text, ref ErrorString);
			if (ResultInt32 == -1)
			{
				LabelRemoveDriverInterfaceResult.Text = "OPC Systems Service not reached.";
			}
			else if (ResultInt32 == 1)
			{
				LabelRemoveDriverInterfaceResult.Text = "Driver Interface successfully removed.";
			}
			else
			{
				LabelRemoveDriverInterfaceResult.Text = ErrorString;
			}
		}

		// The GetDriverInterfaceParameterStrings Function returns an array of Strings containing all property types available for each Driver Interface Group.
		// Returns Empty String Array if service is not reachable.
		// Returns a String Array of property types for all possible Parameters for a Driver Interface Group.
		// NetworkNode is the name of the network node of the OPC Systems Service to connect to.  Leave blank for localhost connection.
		// RemoteSCADAHostingName is the name of the Live Data Cloud OPC Systems Service to connect to.
		private void ButtonGetDriverInterfaceParameterStrings_Click(object sender, System.EventArgs e)
		{
			System.Windows.Forms.Cursor.Current = Cursors.WaitCursor;
			ComboBoxGetDriverInterfaceParameterStrings.Items.Clear();
			string[] Parameters = null;
//INSTANT C# NOTE: Commented this declaration since looping variables in 'foreach' loops are declared in the 'foreach' header in C#:
//			string Parameter = null;
			Parameters = ModuleNetworkNode.OPCSystemsComponent1.GetDriverInterfaceParameterStrings(TextBoxNetworkNode.Text);
			foreach (string Parameter in Parameters)
			{
				ComboBoxGetDriverInterfaceParameterStrings.Items.Add(Parameter);
			}
			if (ComboBoxGetDriverInterfaceParameterStrings.Items.Count > 0)
			{
				ComboBoxGetDriverInterfaceParameterStrings.SelectedIndex = 0;
			}
		}

		private void ComboBoxGetDriverInterfaceParameterStrings_SelectedIndexChanged(object sender, System.EventArgs e)
		{
			TextBoxParameter.Text = ComboBoxGetDriverInterfaceParameterStrings.SelectedItem.ToString();
		}

		// The GetDriverInterface_Parameter_Value Function returns an object value for the Driver Interface Group and Parameter specified.
		// Returns nothing if service is not reachable.
		// Parameter is a String of the Parameter Type desired of the Driver Interface Group.
		// Name is a String of the Driver Interface Group desired.
		// NetworkNode is the name of the network node of the OPC Systems Service to connect to.  Leave blank for localhost connection.
		// ErrorString will be set to Success when function is successful and an error message when in error.
		// RemoteSCADAHostingName is the name of the Live Data Cloud OPC Systems Service to connect to.
		private void ButtonGetDriverInterface_Parameter_Value_Click(object sender, System.EventArgs e)
		{
			System.Windows.Forms.Cursor.Current = Cursors.WaitCursor;
			object ResultObject = null;
			string ErrorString = "";
			ResultObject = ModuleNetworkNode.OPCSystemsComponent1.GetDriverInterface_Parameter_Value(TextBoxParameter.Text, TextBoxDriverInterface.Text, TextBoxNetworkNode.Text, ref ErrorString);
			if (ErrorString == "Success")
			{
				try
				{
					LabelGetDriverInterface_Parameter_ValueResult.Text = ResultObject.ToString();
					TextBoxValueToSet.Text = ResultObject.ToString();
				}
				catch (Exception ex)
				{
					LabelGetDriverInterface_Parameter_ValueResult.Text = "Error converting value to string.";
					TextBoxValueToSet.Text = "";
				}
			}
			else
			{
				LabelGetDriverInterface_Parameter_ValueResult.Text = ErrorString;
				TextBoxValueToSet.Text = "";
			}
		}

		// The GetDriverInterface_Parameter_Values Function returns an array of object values for the Driver Interface Group specified.
		// The order of the array corresponds with the GetDataLoggingParameterStrings Function order.
		// Returns empty array if service is not reachable.
		// Name is a String of the Driver Interface Group desired.
		// NetworkNode is the name of the network node of the OPC Systems Service to connect to.  Leave blank for localhost connection.
		// ErrorString will be set to Success when function is successful and an error message when in error.
		// RemoteSCADAHostingName is the name of the Live Data Cloud OPC Systems Service to connect to.
		private void ButtonGetDriverInterface_Parameter_Values_Click(object sender, System.EventArgs e)
		{
			System.Windows.Forms.Cursor.Current = Cursors.WaitCursor;
			ComboBoxGetDriverInterface_Parameter_Values.Items.Clear();
			object[] ResultObjects = null;
//INSTANT C# NOTE: Commented this declaration since looping variables in 'foreach' loops are declared in the 'foreach' header in C#:
//			object ResultObject = null;
			string ResultString = "";
			Int32 ParameterIndex = 0;
			string ErrorString = "";
			ResultObjects = ModuleNetworkNode.OPCSystemsComponent1.GetDriverInterface_Parameter_Values(TextBoxDriverInterface.Text, TextBoxNetworkNode.Text, ref ErrorString);
			if (ErrorString == "Success")
			{
				foreach (object ResultObject in ResultObjects)
				{
					try
					{
						if (ResultObject == null)
						{
							ResultString = "";
						}
						else
						{
							ResultString = System.Convert.ToString(ResultObject);
						}
						ComboBoxGetDriverInterface_Parameter_Values.Items.Add(ResultString);
					}
					catch (Exception ex)
					{
						ComboBoxGetDriverInterface_Parameter_Values.Items.Add("Error Converting Object");
					}
					ParameterIndex += 1;
				}
				if (ComboBoxGetDriverInterface_Parameter_Values.Items.Count > 0)
				{
					ComboBoxGetDriverInterface_Parameter_Values.SelectedIndex = 0;
				}
			}
			else
			{
				MessageBox.Show(ErrorString, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
			}
		}

		// The SetDriverInterface_Parameter_Value Function sets an object value for the Driver Interface Group and Parameter specified.
		// If the Driver Interface specified does not exist it will be added.
		// Returns -1 if service is not reachable.
		// Returns 0 if the value did not get set correctly.
		// Returns 1 if the function was successful.
		// Parameter is a String of the Parameter Type desired of the Driver Interface Group.
		// Value is the desired value to set.
		// Name is a String of the Driver Interface Group desired.
		// NetworkNode is the name of the network node of the OPC Systems Service to connect to.  Leave blank for localhost connection.
		// ErrorString will be set to Success when function is successful and an error message when in error.
		// RemoteSCADAHostingName is the name of the Live Data Cloud OPC Systems Service to connect to.
		private void ButtonSetDriverInterface_Parameter_Value_Click(object sender, System.EventArgs e)
		{
			System.Windows.Forms.Cursor.Current = Cursors.WaitCursor;
			Int32 ResultInt32 = 0;
			string ErrorString = "";

			ResultInt32 = ModuleNetworkNode.OPCSystemsComponent1.SetDriverInterface_Parameter_Value(TextBoxParameter.Text, TextBoxValueToSet.Text, TextBoxDriverInterface.Text, TextBoxNetworkNode.Text, ref ErrorString);

			if (ResultInt32 == -1)
			{
				LabelSetDataLogging_Parameter_ValueResult.Text = "OPC Systems Service not reached.";
			}
			else if (ResultInt32 == 1)
			{
				LabelSetDataLogging_Parameter_ValueResult.Text = "Parameter Successfully Updated.";
			}
			else
			{
				LabelSetDataLogging_Parameter_ValueResult.Text = ErrorString;
			}
		}

	}
}