﻿//INSTANT C# NOTE: Formerly VB project-level imports:
using System;
using System.Collections;
using System.Data;
using System.Diagnostics;
using System.Drawing;
using System.Windows.Forms;

namespace Example
{
	public partial class FormDataLogging
	{
		// This is an example of high speed data logging with automated setup.

		// The GetNetworkNodes Function returns a list of Network Nodes from the local system as a String Array.
		// Returns empty String Array if no Network Nodes are found.
		internal FormDataLogging()
		{
			InitializeComponent();
		}

		private void ButtonGetNetworkNodes_Click(object sender, System.EventArgs e)
		{
			System.Windows.Forms.Cursor.Current = Cursors.WaitCursor;
			string[] NetworkNodes = null;
//INSTANT C# NOTE: Commented this declaration since looping variables in 'foreach' loops are declared in the 'foreach' header in C#:
//			string NetworkNode = null;
			ComboBoxNetworkNodes.Items.Clear();
			ComboBoxNetworkNodes.Items.Add("localhost");
			ComboBoxNetworkNodes.Items.Add("www.opcsystemsserver.com");
			NetworkNodes = ModuleNetworkNode.OPCSystemsComponent1.GetNetworkNodes();
			if (NetworkNodes.GetLength(0) < 1)
			{
			}
			else
			{
				foreach (string NetworkNode in NetworkNodes)
				{
					ComboBoxNetworkNodes.Items.Add(NetworkNode);
				}
			}
			ComboBoxNetworkNodes.SelectedIndex = 0;
		}

		private void ComboBoxNetworkNodes_SelectedIndexChanged(object sender, System.EventArgs e)
		{
			TextBoxNetworkNode.Text = ComboBoxNetworkNodes.SelectedItem.ToString();
		}

		// Step 1 Add Tags to OPC Systems Service
		private void ButtonAddTags_Click(object sender, System.EventArgs e)
		{
			string ResultString = null;
			string[] CSVStrings = new string[5];
			CSVStrings[0] = "Tag,Value - Data Type";
			CSVStrings[1] = "Data Logging.Tag 1,Integer";
			CSVStrings[2] = "Data Logging.Tag 2,Integer";
			CSVStrings[3] = "Data Logging.Tag 3,Integer";
			CSVStrings[4] = "Data Logging.Trigger,Boolean";
			string ErrorString = "";

			ResultString = ModuleNetworkNode.OPCSystemsComponent1.TagCSVImport(CSVStrings, TextBoxNetworkNode.Text, ref ErrorString);
			if (ErrorString == "Success")
			{
				LabelTagCSVImportResult.Text = ResultString;
			}
			else
			{
				LabelTagCSVImportResult.Text = ErrorString;
			}
		}

		// Step 2 Setup Data Logging
		private void ButtonSetupDataLogging_Click(object sender, System.EventArgs e)
		{
			// Check if configuratin is valid
			if (CheckBoxLogToDB.Checked)
			{
				if (ComboBoxProvider.SelectedItem.ToString() == "SQLServer" || ComboBoxProvider.SelectedItem.ToString() == "mySQL")
				{
					if (string.IsNullOrEmpty(TextBoxDBServer.Text))
					{
						MessageBox.Show("Database Server is not specified", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
						return;
					}
				}
			}

			string FinalResults = null;

			// Create or update data logging group
			string ResultString = null;
			string[] CSVStrings = new string[2];
			CSVStrings[0] = "Logging Group Name,Logging Type,Logging Active,Tag For Event Driven Logging,Use MilliSecond Field,Use MicroSecond Field,Use NanoSecond Field,Log To DB,DB Provider,DB Server Name,Database Name,Table Name,Use WinNT Authentication,DB User Name,DB Password,Log To CSV,Path For CSV File Name,CSV File Name,Last Column";
			CSVStrings[1] = "Data Logging Example,EventDriven,1,Data Logging.Trigger.Value,1,1,1," + CheckBoxLogToDB.Checked.ToString() + "," + ComboBoxProvider.SelectedItem.ToString() + "," + TextBoxDBServer.Text + "," + TextBoxDatabase.Text + "," + TextBoxTable.Text + "," + CheckBoxUseWindowsAuthentication.Checked.ToString() + "," + TextBoxUserName.Text + "," + TextBoxPassword.Text + "," + CheckBoxLogToCSV.Checked.ToString() + "," + TextBoxCSVPath.Text + "," + TextBoxCSVFile.Text + ",Last Column";
			string ErrorString = "";

			ResultString = ModuleNetworkNode.OPCSystemsComponent1.DataLoggingCSVImport(CSVStrings, TextBoxNetworkNode.Text, ref ErrorString);
			if (ErrorString == "Success")
			{
				FinalResults = ResultString + "\r" + "\n";
			}
			else
			{
				LabelSetupDataLoggingResult.Text = ErrorString;
				MessageBox.Show(ErrorString, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
				return;
			}

			// Add Fields
			Int32 ResultInt32 = 0;
			object[] ArrayToSend = new object[14];
			string[] Field1Tags = new string[1];
			string[] Field2Tags = new string[1];
			string[] Field3Tags = new string[1];
			ArrayToSend[0] = 2; // Version
			ArrayToSend[1] = 3; // Number of Fields
			ArrayToSend[2] = "Tag1"; // First Field Name
			ArrayToSend[3] = "Tag2"; // Second Field Name
			ArrayToSend[4] = "Tag3"; // Third Field Name
			Field1Tags[0] = "Data Logging.Tag 1.Value";
			ArrayToSend[5] = Field1Tags;
			Field2Tags[0] = "Data Logging.Tag 2.Value";
			ArrayToSend[6] = Field2Tags;
			Field3Tags[0] = "Data Logging.Tag 3.Value";
			ArrayToSend[7] = Field3Tags;
			ArrayToSend[8] = "Integer"; // Data Type for first field
			ArrayToSend[9] = "Integer"; // Data Type for second field
			ArrayToSend[10] = "Integer"; // Data Type for third field
			ArrayToSend[11] = 100; // Length of text for first field if String field
			ArrayToSend[12] = 100; // Length of text for second field if String field
			ArrayToSend[13] = 100; // Length of text for third field if String field

			ResultInt32 = ModuleNetworkNode.OPCSystemsComponent1.SetDataLogging_Parameter_Value("DBFields", ArrayToSend, "Data Logging Example", TextBoxNetworkNode.Text, ref ErrorString);
			if (ResultInt32 == -1)
			{
				LabelSetupDataLoggingResult.Text = "OPC Systems Service not reached.";
				MessageBox.Show("OPC Systems Service not reached.", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
				return;
			}
			else if (ResultInt32 == 1)
			{
				FinalResults += "Database Fields Successfully Updated.";
			}
			else
			{
				LabelSetupDataLoggingResult.Text = ErrorString;
				MessageBox.Show(ErrorString, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
				return;
			}
			LabelSetupDataLoggingResult.Text = FinalResults;
		}

		// Step 3 Adding values to be logged
		private void ButtonAddValues_Click(object sender, System.EventArgs e)
		{
			string NetworkNodeForData = "";
			if (!string.IsNullOrEmpty(TextBoxNetworkNode.Text) && TextBoxNetworkNode.Text.ToLower() != "localhost")
			{
				NetworkNodeForData = "\\\\" + TextBoxNetworkNode.Text + "\\";
			}

			string[] TagsToSend = new string[5000];
			object[] ValuesToSend = new object[5000];
			DateTime[] TimeStampsToSend = new DateTime[5000];
			Int32 Index = 0;
			DateTime TimeToLog = DateTime.Now;
			for (Index = 0; Index <= 999; Index++)
			{
				TagsToSend[Index * 5] = NetworkNodeForData + "Data Logging.Tag 1.Value";
				TagsToSend[Index * 5 + 1] = NetworkNodeForData + "Data Logging.Tag 2.Value";
				TagsToSend[Index * 5 + 2] = NetworkNodeForData + "Data Logging.Tag 3.Value";
				TagsToSend[Index * 5 + 3] = NetworkNodeForData + "Data Logging.Trigger.Value";
				TagsToSend[Index * 5 + 4] = NetworkNodeForData + "Data Logging.Trigger.Value";

				ValuesToSend[Index * 5] = Index;
				ValuesToSend[Index * 5 + 1] = Index;
				ValuesToSend[Index * 5 + 2] = Index;
				ValuesToSend[Index * 5 + 3] = true; // Change in Trigger will cause new record
				ValuesToSend[Index * 5 + 4] = false;

				TimeStampsToSend[Index * 5] = TimeToLog;
				TimeStampsToSend[Index * 5 + 1] = TimeToLog;
				TimeStampsToSend[Index * 5 + 2] = TimeToLog;
				TimeStampsToSend[Index * 5 + 3] = TimeToLog; // This will be the Timestamp for the record
				TimeStampsToSend[Index * 5 + 4] = TimeToLog;

				TimeToLog = TimeToLog.AddTicks(1);
			}

			OpcControlsData1.WriteTags(TagsToSend, ValuesToSend, TimeStampsToSend);
		}

		private void CheckBoxLogToDB_CheckedChanged(object sender, System.EventArgs e)
		{
			ComboBoxProvider.Enabled = CheckBoxLogToDB.Checked;
			if (ComboBoxProvider.SelectedItem == null)
			{
				TextBoxDBServer.Enabled = false;
			}
			else
			{
				TextBoxDBServer.Enabled = CheckBoxLogToDB.Checked && (ComboBoxProvider.SelectedItem.ToString() == "SQLServer" || ComboBoxProvider.SelectedItem.ToString() == "mySQL");
			}
			TextBoxDatabase.Enabled = CheckBoxLogToDB.Checked;
			TextBoxTable.Enabled = CheckBoxLogToDB.Checked;
			CheckBoxUseWindowsAuthentication.Enabled = CheckBoxLogToDB.Checked;
			TextBoxUserName.Enabled = CheckBoxLogToDB.Checked && !(CheckBoxUseWindowsAuthentication.Checked);
			TextBoxPassword.Enabled = CheckBoxLogToDB.Checked && !(CheckBoxUseWindowsAuthentication.Checked);
		}

		private void ComboBoxProvider_SelectedIndexChanged(object sender, System.EventArgs e)
		{
			if (ComboBoxProvider.SelectedItem == null)
			{
				TextBoxDBServer.Enabled = false;
				return;
			}
			TextBoxDBServer.Enabled = CheckBoxLogToDB.Checked && (ComboBoxProvider.SelectedItem.ToString() == "SQLServer" || ComboBoxProvider.SelectedItem.ToString() == "mySQL");
		}

		private void CheckBoxLogToCSV_CheckedChanged(object sender, System.EventArgs e)
		{
			TextBoxCSVPath.Enabled = CheckBoxLogToCSV.Checked;
			TextBoxCSVFile.Enabled = CheckBoxLogToCSV.Checked;
		}

		private void FormDataLogging_Load(object sender, System.EventArgs e)
		{
			ComboBoxProvider.SelectedIndex = 0;
		}

		private void ButtonViewVideo_Click(object sender, System.EventArgs e)
		{
			try
			{
				System.Diagnostics.Process.Start("http://www.opcsystems.com/highspeedlogging_video.htm");
			}
			catch (Exception ex)
			{

			}
		}
	}
}